@@ -34,7 +34,7 @@ def claim_product(api_client, recaptcha_solution):
     logger.info("Start grabbing ebook...")
 
     free_learning_html = api_client.get(PACKT_FREE_LEARNING_URL).text
-    offer_id_match = re.search(re.compile("offerId=\"(.*?)\""), free_learning_html)
+    offer_id_match = re.search(re.compile("[oO][fF][fF][eE][rR][iI][dD]=\"(.*?)\""), free_learning_html)
     offer_id = offer_id_match.group(1) if offer_id_match else None
 
     # Handle case when there is no Free Learning offer
